---
title: "ADS1015"
linkTitle: "ADS1015"
weight: 4
description: >
  Texas Instruments Analog-Digital Converter
---

## Registers

### ADC config
Describes the specifics of the sensing implementation

### ADC Value
Conversion register contains the result of the last conversion

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_ADS1015 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_